<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://wpuzman.com
 * @since      1.0.0
 *
 * @package    Edd_Paytr
 * @subpackage Edd_Paytr/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Edd_Paytr
 * @subpackage Edd_Paytr/admin
 * @author     wpuzman <iletisim@wpuzman.com>
 */
class Edd_Paytr_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The options name to be used in this plugin
     *
     * @since    1.0.0
     * @access   private
     * @var      string $option_name Option name of this plugin
     */
    private $option_name = 'edd_paytr';

    /**
     * @var
     * Plugin options
     */
    var $merchant_id;
    var $merchant_key;
    var $merchant_salt;
    var $debug;
    var $delete_options;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->merchant_id = !empty( get_option( $this->option_name . '_merchant_id' ) ) ? get_option( $this->option_name . '_merchant_id' ) : '';
        $this->merchant_key = !empty( get_option( $this->option_name . '_merchant_key' ) ) ? get_option( $this->option_name . '_merchant_key' ) : '';
        $this->merchant_salt = !empty( get_option( $this->option_name . '_merchant_salt' ) ) ? get_option( $this->option_name . '_merchant_salt' ) : '';
        $this->debug = !empty( get_option( $this->option_name . '_debug' ) ) ? true : false;
        $this->delete_options = !empty( get_option( $this->option_name . '_delete_options' ) ) ? true : false;

    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Edd_Paytr_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Edd_Paytr_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/edd-paytr-admin.css', array(), $this->version, 'all' );

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Edd_Paytr_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Edd_Paytr_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/edd-paytr-admin.js', array( 'jquery' ), $this->version, false );

    }

    /**
     * @param $gateways
     * @return mixed
     * Register payment gateway to edd payment options
     */
    public function register_edd_payment_gateway( $gateways ) {
        $gateways[ 'paytr' ] = array( 'admin_label' => 'Paytr', 'checkout_label' => __( 'Kredi/Banka Kartı', 'edd-paytr' ) );
        return $gateways;
    }

    /**
     * Add an options page under the Settings submenu
     *
     * @since  1.0.0
     */
    public function add_options_page() {

        add_options_page(
            __( 'EDD Paytr', 'edd-paytr' ),
            __( 'EDD Paytr', 'edd-paytr' ),
            'manage_options',
            $this->plugin_name,
            array( $this, 'display_options_page' )
        );

    }

    /**
     * Register settings
     *
     * @since 1.0.0
     */
    public function register_setting() {
        add_settings_section(
            $this->option_name . '_options_section',
            __( 'Mağaza Ayarları', 'edd-paytr' ),
            array( $this, $this->option_name . '_general_cb' ),
            $this->plugin_name
        );

        add_settings_field(
            $this->option_name . '_merchant_id',
            __( 'Mağaza No', 'edd-paytr' ),
            array( $this, $this->option_name . '_merchant_id_cb' ),
            $this->plugin_name,
            $this->option_name . '_options_section',
            array( 'label_for' => $this->option_name . '_merchant_id' )
        );

        add_settings_field(
            $this->option_name . '_merchant_key',
            __( 'Mağaza Parola', 'edd-paytr' ),
            array( $this, $this->option_name . '_merchant_key_cb' ),
            $this->plugin_name,
            $this->option_name . '_options_section',
            array( 'label_for' => $this->option_name . '_merchant_key' )
        );

        add_settings_field(
            $this->option_name . '_merchant_salt',
            __( 'Mağaza Gizli Anahtar', 'edd-paytr' ),
            array( $this, $this->option_name . '_merchant_salt_cb' ),
            $this->plugin_name,
            $this->option_name . '_options_section',
            array( 'label_for' => $this->option_name . '_merchant_salt' )
        );

        add_settings_field(
            $this->option_name . '_debug',
            __( 'Hata Ayıklama', 'edd-paytr' ),
            array( $this, $this->option_name . '_debug_cb' ),
            $this->plugin_name,
            $this->option_name . '_options_section',
            array( 'label_for' => $this->option_name . '_debug' )
        );

        add_settings_field(
            $this->option_name . '_delete_options',
            __( 'Eklenti Silindiğinde Bilgileri Temizle', 'edd-paytr' ),
            array( $this, $this->option_name . '_delete_options_cb' ),
            $this->plugin_name,
            $this->option_name . '_options_section',
            array( 'label_for' => $this->option_name . '_delete_options' )
        );

        register_setting( $this->plugin_name, $this->option_name . '_merchant_id', 'sanitize_text_field' );
        register_setting( $this->plugin_name, $this->option_name . '_merchant_key', 'sanitize_text_field' );
        register_setting( $this->plugin_name, $this->option_name . '_merchant_salt', 'sanitize_text_field' );
        register_setting( $this->plugin_name, $this->option_name . '_debug', 'sanitize_text_field' );
        register_setting( $this->plugin_name, $this->option_name . '_delete_options', 'sanitize_text_field' );
    }

    public function edd_paytr_general_cb() { ?>
		<p class="decription"><?php printf( __( 'Paytr ayarlarında BİLDİRİM URL kısmını <strong>%s</strong> şeklinde ayarlamayı unutmayın!' ), 'https://site.com/?paytr=paytr_response' ); ?></p>
		<p class="decription"><?php esc_html_e( 'Paytr est modu için Easy Digitals Downloads ödeme ayarlarından test modunu etkinleştirebilirsiniz.', 'edd-paytr' ); ?></p>
    <?php }

    public function edd_paytr_merchant_id_cb() { ?>
		<input class="regular-text" type="text" name="<?php echo $this->option_name . '_merchant_id' ?>" id="<?php echo $this->option_name . '_merchant_id' ?>" value="<?php echo esc_attr( $this->merchant_id ) ?>">
    <?php }

    public function edd_paytr_merchant_key_cb() { ?>
		<input class="regular-text" type="text" name="<?php echo $this->option_name . '_merchant_key' ?>" id="<?php echo $this->option_name . '_merchant_key' ?>" value="<?php echo esc_attr( $this->merchant_key ) ?>">
    <?php }

    public function edd_paytr_merchant_salt_cb() { ?>
		<input class="regular-text" type="text" name="<?php echo $this->option_name . '_merchant_salt' ?>" id="<?php echo $this->option_name . '_merchant_salt' ?>" value="<?php echo esc_attr( $this->merchant_salt ) ?>">
    <?php }

    public function edd_paytr_debug_cb() { ?>
		<input class="regular-text" type="checkbox" name="<?php echo $this->option_name . '_debug' ?>" id="<?php echo $this->option_name . '_debug' ?>"<?php checked( $this->debug ); ?>>
    <?php }

    public function edd_paytr_delete_options_cb() { ?>
		<input class="regular-text" type="checkbox" name="<?php echo $this->option_name . '_delete_options' ?>" id="<?php echo $this->option_name . '_delete_options' ?>"<?php checked( $this->delete_options ); ?>>
    <?php }

    /**
     * Render the options page for plugin
     *
     * @since  1.0.0
     */
    public function display_options_page() {
        include_once 'partials/edd-paytr-admin-display.php';
    }

    /**
     * @param $links
     * @return array
     * Add settings link
     */
    public function settings_link( $links ) {
        $settings_link = array(
            '<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __( 'Ayarlar', 'edd-paytr' ) . '</a>',
        );
        return array_merge( $settings_link, $links );
    }

}
