<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://wpuzman.com
 * @since      1.0.0
 *
 * @package    Edd_Paytr
 * @subpackage Edd_Paytr/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Edd_Paytr
 * @subpackage Edd_Paytr/public
 * @author     wpuzman <iletisim@wpuzman.com>
 */
class Edd_Paytr_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * @var
     * Initialize paytr global
     */
    private $edd_options;

    /**
     * The options name to be used in this plugin
     *
     * @since    1.0.0
     * @access   private
     * @var      string $option_name Option name of this plugin
     */
    private $option_name = 'edd_paytr';

    /**
     * @var
     * Plugin options
     */
    var $merchant_id;
    var $merchant_key;
    var $merchant_salt;
    var $debug;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of the plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        global $edd_options;
        $this->edd_options = $edd_options;

        $this->merchant_id = ! empty( get_option( $this->option_name . '_merchant_id' ) ) ? get_option( $this->option_name . '_merchant_id' ) : '';
        $this->merchant_key = ! empty( get_option( $this->option_name . '_merchant_key' ) ) ? get_option( $this->option_name . '_merchant_key' ) : '';
        $this->merchant_salt = ! empty( get_option( $this->option_name . '_merchant_salt' ) ) ? get_option( $this->option_name . '_merchant_salt' ) : '';
        $this->debug = ! empty( get_option( $this->option_name . '_debug' ) ) ? true : false;

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Edd_Paytr_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Edd_Paytr_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/edd-paytr-public.css', array(), $this->version, 'all' );

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Edd_Paytr_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Edd_Paytr_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/edd-paytr-public.js', array( 'jquery' ), $this->version, false );

    }

    /**
     * Display required form fields
     * Address etc.
     */
    public function display_fields() {
        ob_start();
        edd_default_cc_address_fields();
        echo ob_get_clean();
    }

    /**
     * Display phone field
     * Paytr requires phone number.
     */
    public function display_phone() {
        $phone = get_user_meta( get_current_user_id(), 'edd_phone', true );
        ob_start();
        ?>
		<p id="edd-phone-wrap">
			<label class="edd-label"><?php _e( 'Telefon Numarası', 'edd-paytr' ); ?></label>
			<span class="edd-required-indicator">*</span>
			<input type="text" autocomplete="off" name="edd_phone" class="user-phone edd-input required" placeholder="<?php _e( 'Telefon numaranızı giriniz...', 'edd-paytr' ); ?>" value="<?php echo ! empty( $phone ) ? esc_attr( $phone ) : ''; ?>" required>
		</p>
        <?php
        echo ob_get_clean();
    }

    function required_fields( $required_fields ) {
        $required_fields[ 'edd_last' ] = array(
            'error_id'      => 'invalid_last_name',
            'error_message' => __( 'Lütfen soyadınızı girin.', 'edd-paytr' )
        );
        $required_fields[ 'edd_phone' ] = array(
            'error_id'      => 'invalid_phone',
            'error_message' => __( 'Lütfen telefon numaranızı girin.', 'edd-paytr' )
        );
        $required_fields[ 'card_address' ] = array(
            'error_id'      => 'invalid_address',
            'error_message' => __( 'Lütfen adresinizi girin.', 'edd-paytr' )
        );
        return $required_fields;
    }

    public function call_iframe( $args ) {
        $defaults = array(
            'test_mode'     => 0,
            'user_email'    => '',
            'merchant_id'   => '',
            'merchant_key'  => '',
            'merchant_salt' => '',
            'price'         => '',
            'merchant_oid'  => '',
            'user_name'     => '',
            'user_address'  => '',
            'user_phone'    => '',
            'success_url'   => '',
            'error_url'     => '',
            'user_basket'   => '',
            'debug'         => 0,
            'installment'   => 0
        );

        $args = wp_parse_args( $args, $defaults );

        $merchant_id = $args[ 'merchant_id' ];
        $merchant_key = $args[ 'merchant_key' ];
        $merchant_salt = $args[ 'merchant_salt' ];
        $email = $args[ 'user_email' ];
        $payment_amount = $args[ 'price' ] * 100;
        $merchant_oid = $args[ 'merchant_oid' ];
        $user_name = $args[ 'user_name' ];
        $user_address = $args[ 'user_address' ];
        $user_phone = $args[ 'user_phone' ];
        $merchant_ok_url = $args[ 'success_url' ];
        $merchant_fail_url = $args[ 'error_url' ];
        $user_basket = $args[ 'user_basket' ];
        if( isset( $_SERVER[ "HTTP_CLIENT_IP" ] ) ) {
            $ip = $_SERVER[ "HTTP_CLIENT_IP" ];
        } elseif( isset( $_SERVER[ "HTTP_X_FORWARDED_FOR" ] ) ) {
            $ip = $_SERVER[ "HTTP_X_FORWARDED_FOR" ];
        } else {
            $ip = $_SERVER[ "REMOTE_ADDR" ];
        }
        $user_ip = $ip;
        $timeout_limit = "30";
        $debug_on = $args[ 'debug' ];
        $test_mode = $args[ 'test_mode' ];
        $no_installment = $args[ 'installment' ];
        $max_installment = 0;
        $currency = edd_get_currency();
        $hash_str = $merchant_id . $user_ip . $merchant_oid . $email . $payment_amount . $user_basket . $no_installment . $max_installment . $currency . $test_mode;
        $paytr_token = base64_encode( hash_hmac( 'sha256', $hash_str . $merchant_salt, $merchant_key, true ) );
        $post_vals = array(
            'merchant_id'       => $merchant_id,
            'user_ip'           => $user_ip,
            'merchant_oid'      => $merchant_oid,
            'email'             => $email,
            'payment_amount'    => $payment_amount,
            'paytr_token'       => $paytr_token,
            'user_basket'       => $user_basket,
            'debug_on'          => $debug_on,
            'no_installment'    => $no_installment,
            'max_installment'   => $max_installment,
            'user_name'         => $user_name,
            'user_address'      => $user_address,
            'user_phone'        => $user_phone,
            'merchant_ok_url'   => $merchant_ok_url,
            'merchant_fail_url' => $merchant_fail_url,
            'timeout_limit'     => $timeout_limit,
            'currency'          => $currency,
            'test_mode'         => $test_mode
        );

        $result = wp_remote_post( 'https://www.paytr.com/odeme/api/get-token', array(
                'method'      => 'POST',
                'httpversion' => '1.0',
                'sslverify'   => false,
                'body'        => $post_vals )
        );

        $body = wp_remote_retrieve_body( $result );
        $response = json_decode( $body, 1 );

        $token = '';
        if( $response[ 'status' ] == 'success' ) {
            $token = $response[ 'token' ];
        } else {
            wp_die( "PAYTR IFRAME failed. reason:" . $response[ 'reason' ] );
        }
        ?>
		<script src="https://www.paytr.com/js/iframeResizer.min.js"></script>
		<iframe src="https://www.paytr.com/odeme/guvenli/<?php echo $token; ?>" id="paytriframe" frameborder="0" scrolling="no" style="width: 100%;"></iframe>
	    <script type="text/javascript">
            setInterval(function(){
                iFrameResize({},'#paytriframe');
            }, 1000);
	    </script>
        <?php
    }

    public function process_payment( $purchase_data ) {
        if( ! isset( $purchase_data[ 'post_data' ][ 'edd-gateway' ] ) )
            return;

        if( ! isset( $_POST[ 'card_address' ] ) || empty( $_POST[ 'card_address' ] ) )
            edd_set_error( 'empty_phone', __( 'Lütfen adres bilgisi girin.', 'edd-paytr' ) );

        if( is_user_logged_in() ) {
            update_user_meta( get_current_user_id(), 'edd_phone', sanitize_text_field( trim( $_POST[ 'edd_phone' ] ) ) );
        }

        $errors = edd_get_errors();
        if( ! $errors ) {
            $purchase_summary = edd_get_purchase_summary( $purchase_data );

            $payment = array(
                'price'        => $purchase_data[ 'price' ],
                'date'         => $purchase_data[ 'date' ],
                'user_email'   => $purchase_data[ 'user_email' ],
                'purchase_key' => $purchase_data[ 'purchase_key' ],
                'currency'     => $this->edd_options[ 'currency' ],
                'downloads'    => $purchase_data[ 'downloads' ],
                'cart_details' => $purchase_data[ 'cart_details' ],
                'user_info'    => $purchase_data[ 'user_info' ],
                'status'       => 'pending'
            );

            $payment = edd_insert_payment( $payment );

            if( $payment ) {
                $session = edd_get_purchase_session();
                $orderID = $purchase_id = edd_get_purchase_id_by_key( $session[ 'purchase_key' ] );
                $customer_name = substr( $purchase_data[ 'post_data' ][ 'edd_first' ] . ' ' . $purchase_data[ 'post_data' ][ 'edd_last' ], 0, 100 );

                $billing_address_1 = substr( $purchase_data[ 'post_data' ][ 'card_address' ], 0, 100 );
                $billing_address_2 = substr( $purchase_data[ 'post_data' ][ 'card_address_2' ], 0, 100 );
                $customer_address = $billing_address_1 . ' ' . $billing_address_2;

                $phone = substr( $purchase_data[ 'post_data' ][ 'edd_phone' ], 0, 100 );

                $user_basket = array();
                $cart_items = $purchase_data[ 'cart_details' ];

                foreach( $cart_items as $cart_item ) {
                    $user_basket[] = array( $cart_item[ 'id' ] . ' ' . $cart_item[ 'name' ], $cart_item[ 'price' ], $cart_item[ 'quantity' ] );
                }

                $args = array(
                    'price'         => $purchase_data[ 'price' ],
                    'merchant_id'   => $this->merchant_id,
                    'merchant_key'  => $this->merchant_key,
                    'merchant_salt' => $this->merchant_salt,
                    'debug'         => $this->debug ? 1 : 0,
                    'merchant_oid'  => $orderID,
                    'user_email'    => $purchase_data[ 'user_email' ],
                    'user_basket'   => base64_encode( json_encode( $user_basket ) ),
                    'user_name'     => $customer_name,
                    'user_address'  => $customer_address,
                    'user_phone'    => $phone,
                    'success_url'   => edd_get_success_page_uri(),
                    'error_url'     => edd_get_checkout_uri(),
                    'test_mode'     => edd_is_test_mode() ? 1 : 0,
                );

                edd_empty_cart();
                $this->call_iframe( $args );
            }
        } else {
            edd_send_back_to_checkout();
        }
    }

    /**
     * Complete order by order_id
     * order_id comes from paytr as merchant_oid
     */
    function update_order() {
        if( isset( $_GET[ 'paytr' ] ) && $_GET[ 'paytr' ] == 'paytr_response' ) {
            $merchant_key = $this->merchant_key;
            $merchant_salt = $this->merchant_salt;

            $post = $_POST;
            $hash = base64_encode( hash_hmac( 'sha256', $post[ 'merchant_oid' ] . $merchant_salt . $post[ 'status' ] . $post[ 'total_amount' ], $merchant_key, true ) );

            if( $hash != $_POST[ 'hash' ] ) {
                die( 'PAYTR notification failed: bad hash' );
            }

            if( $_POST[ 'status' ] == 'success' ) {
                edd_update_payment_status( (int)$_POST[ 'merchant_oid' ], 'complete' );
            } else {
                edd_update_payment_status( (int)$_POST[ 'merchant_oid' ], 'failed' );
            }

            echo 'OK';
            exit;
        }
    }

}
